<template>
  <Inner>
    <template>
      <div v-if="page_content != null">
        <section class="cms_banner">
          <div class="container">
            <div class="row">
              <div class="col-12">
                <h1>Contact us</h1>
                <div class="inner_breadcrumb"><a href="/">Home</a> / Contact us</div>
              </div>
            </div>
          </div>
        </section>
        <div class="cms_content contact_cont">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-12 col-md-6">
                <h2>Contact info</h2>
                <ul>
                  <li>
                    <h3>Arrange your rentals today</h3>
                    <p>One of the best advantages of hiring from Perth Rentals Hire; if any of our equipment breaks down we
                    come out and fix it or replace it.</p>

                  </li>
                  <li>
                    <span class="material-icons-outlined">phone</span>
                    <label>Call Customer Service</label>
                    <a href="tel:0893797344">(08) 9379 7344</a>
                  </li>
                </ul>
              </div>
              <div class="col-xs-12 col-sm-12 col-md-6 contact_form">
                <contactUsForm></contactUsForm>
              </div>
            </div>
          </div>
        </div>
      </div>
      <div v-else>
        <div class="container">
          <div class="row">
            <div class="col-12">
              <h5>404 Page not found</h5>
            </div>
          </div>
        </div>
      </div>
    </template>
  </Inner>
</template>
<script>
import Inner from '~/layouts/inner.vue'
import options from '~/assets/options';
import contactUsForm from '~/components/front-end/contact-us-form.vue';
export default {
  components: { Inner, contactUsForm },
  async asyncData({ $axios, params, store,error }) {
    if(!store.state.front_end_data.url_available) {
          return error({ statusCode: 404, message: 'Page Not Found' })
        }
    let current_host = store.state.front_end_data.domain_id;
    const data = await $axios.$get(`/api/page-detail/contact-us/${current_host}`);
    if (data.error) {
      return { page_content: null };
    }
    return { page_content: data };
  },
  data() {
    return {
      domain: this.$store.state.front_end_data.domain,
    }
  },
  head() {
    if (this.page_content != null) {
      return {
        title: `${this.page_content.meta_title} - ${this.domain.name}`,
        script: [
          {
            src: '/front-end/js/google-analytics.js'
          }
        ],
        meta: [
          {
            hid: 'description',
            name: 'description',
            content: `${this.page_content.meta_description}`
          },
          {
            hid: 'og:title',
            name: 'og:title',
            content: `${this.page_content.meta_title}`
          },
          {
            hid: 'og:description',
            name: 'og:description',
            content: `${this.page_content.meta_description}`
          }, {
            hid: 'og:type',
            name: 'og:type',
            content: "Website"
          },
          {
            hid: 'og:url',
            name: 'og:url',
            content: this.domain.url + this.$route.fullPath
          },
          {
            hid: 'og:url',
            name: 'og:site_name',
            content: this.domain.name
          },
          {
            hid: 'og:image',
            name: 'og:image',
            content: "/images/logo.png"
          },
          {
            hid: 'name',
            name: 'twitter:card',
            content: "summary_large_image"
          },
          {
            hid: 'name',
            name: 'twitter:title',
            content: `${this.page_content.meta_title}`
          },
          {
            hid: 'name',
            name: 'twitter:description',
            content: `${this.page_content.meta_description}`
          },
          {
            hid: 'name',
            name: 'twitter:image:src',
            content: "/images/logo.png"
          },
          {
            hid: 'name',
            name: 'twitter:site',
            content: this.domain.name
          },
        ],
      }
    }
  },
  mounted() {
    setTimeout(() => {
      $('#contact-us').addClass('active_item');
    }, 0);
  },
}
</script>

